Author: timfox
Date: 2010-01-06 07:38:23 -0500 (Wed, 06 Jan 2010)
New Revision: 8736
Added:
trunk/src/main/org/hornetq/api/core/client/loadbalance/package-info.java
trunk/src/main/org/hornetq/api/core/package-info.java
Modified:
trunk/src/main/org/hornetq/api/core/client/package-info.java
trunk/src/main/org/hornetq/api/core/management/package-info.java
trunk/src/main/org/hornetq/api/jms/management/package-info.java
trunk/src/main/org/hornetq/api/jms/package-info.java
Log:
added missing package-info.java classes
Added: trunk/src/main/org/hornetq/api/core/client/loadbalance/package-info.java
===================================================================
--- trunk/src/main/org/hornetq/api/core/client/loadbalance/package-info.java
(rev 0)
+++ trunk/src/main/org/hornetq/api/core/client/loadbalance/package-info.java 2010-01-06
12:38:23 UTC (rev 8736)
@@ -0,0 +1,18 @@
+/*
+ * Copyright 2009 Red Hat, Inc.
+ * Red Hat licenses this file to you under the Apache License, version
+ * 2.0 (the "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
http://www.apache.org/licenses/LICENSE-2.0
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+ * implied. See the License for the specific language governing
+ * permissions and limitations under the License.
+ */
+
+/**
+ * HornetQ client side connection load balancing policies
+ */
+package org.hornetq.api.core.client.loadbalance;
+
Modified: trunk/src/main/org/hornetq/api/core/client/package-info.java
===================================================================
--- trunk/src/main/org/hornetq/api/core/client/package-info.java 2010-01-06 12:19:47 UTC
(rev 8735)
+++ trunk/src/main/org/hornetq/api/core/client/package-info.java 2010-01-06 12:38:23 UTC
(rev 8736)
@@ -12,7 +12,7 @@
*/
/**
- * Core API to produce and consume messages.
+ * HornetQ core client messaging API to produce and consume messages.
* <br>
* This package defines the API used by HornetQ clients to produce and consume messages.
*/
Modified: trunk/src/main/org/hornetq/api/core/management/package-info.java
===================================================================
--- trunk/src/main/org/hornetq/api/core/management/package-info.java 2010-01-06 12:19:47
UTC (rev 8735)
+++ trunk/src/main/org/hornetq/api/core/management/package-info.java 2010-01-06 12:38:23
UTC (rev 8736)
@@ -12,7 +12,7 @@
*/
/**
- * management API for HornetQ servers and its Core resources.
+ * Management API for HornetQ servers and its Core resources.
* <br>
* HornetQ can be managed either using JMX or by sending management messages to the
* server's special management address. Please refer to the user manual for more
information.
Added: trunk/src/main/org/hornetq/api/core/package-info.java
===================================================================
--- trunk/src/main/org/hornetq/api/core/package-info.java (rev 0)
+++ trunk/src/main/org/hornetq/api/core/package-info.java 2010-01-06 12:38:23 UTC (rev
8736)
@@ -0,0 +1,20 @@
+/*
+ * Copyright 2009 Red Hat, Inc.
+ * Red Hat licenses this file to you under the Apache License, version
+ * 2.0 (the "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
http://www.apache.org/licenses/LICENSE-2.0
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+ * implied. See the License for the specific language governing
+ * permissions and limitations under the License.
+ */
+
+/**
+ * HornetQ core messaging API
+ * <br>
+ * This package defines the core API
+ */
+package org.hornetq.api.core;
+
Modified: trunk/src/main/org/hornetq/api/jms/management/package-info.java
===================================================================
--- trunk/src/main/org/hornetq/api/jms/management/package-info.java 2010-01-06 12:19:47
UTC (rev 8735)
+++ trunk/src/main/org/hornetq/api/jms/management/package-info.java 2010-01-06 12:38:23
UTC (rev 8736)
@@ -12,7 +12,7 @@
*/
/**
- * management API for HornetQ JMS resources.
+ * Management API for HornetQ JMS resources.
* <br>
* HornetQ JMS resources can be managed either using JMX or by sending JMS management
messages to the
* server's special management address. Please refer to the user manual for more
information.
Modified: trunk/src/main/org/hornetq/api/jms/package-info.java
===================================================================
--- trunk/src/main/org/hornetq/api/jms/package-info.java 2010-01-06 12:19:47 UTC (rev
8735)
+++ trunk/src/main/org/hornetq/api/jms/package-info.java 2010-01-06 12:38:23 UTC (rev
8736)
@@ -12,10 +12,7 @@
*/
/**
* Implementation of the JMS Destinations.
* <br>
* Classes in this package can be instantiated directly
* if JMS destinations are not looked up in JNDI.
*
*/
package org.hornetq.api.jms;
@@ -12,10 +12,7 @@
*/
/**
- * Implementation of the JMS Destinations.
- * <br>
- * Classes in this package can be instantiated directly
- * if JMS destinations are not looked up in JNDI.
+ * This package contains classes that relate to the HornetQ JMS implementation
*
*/